%global commit 8902b68d00ebf1f915b7694a64d65d7e14cf2117
%global date 20180426

%global shortcommit %(c=%{commit}; echo ${c:0:7})

%global with_check 1

%bcond_without python3

Name:           libCombine
Summary:        C++ library for working with the COMBINE Archive format
Version:        0.2.2
Release:        3.%{date}git%{shortcommit}%{?dist}
URL:            https://github.com/sbmlteam/libCombine
Source0:        https://github.com/sbmlteam/libCombine/archive/%{commit}.zip#/libCombine-%{commit}.zip

# Header files and part of source code is released under LGPLv2+ license
License:        BSD and LGPLv2+

BuildRequires: cmake
BuildRequires: gcc-c++
BuildRequires: libsbml-devel
BuildRequires: libnuml-devel
BuildRequires: expat-devel
BuildRequires: libxml2-devel
BuildRequires: bzip2-devel
BuildRequires: xerces-c-devel
BuildRequires: zlib-devel
BuildRequires: zipper-devel
BuildRequires: minizip-devel

%description
LibCombine implements a C++ API library providing support for the
Combine Archive. The library is written after the likeness of
libSBML (and in fact some classes have been generated using DEVISER).
Thus even thought he core is written in C++, the classes can be
accessed via SWIG from .NET, Java and Python.

%package devel
Summary: Development files of %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: libsbml-devel%{?_isa}

%description devel
This package provides header, shared and static library files
of %{name}.

%package static
Summary: Static library of %{name}
Requires: %{name}-devel%{?_isa} = %{version}-%{release}

%description static
This package provides static library file of %{name}.

%if %{with python3}
%package -n python3-%{name}
BuildRequires:  python3-devel, swig
Summary:  Python 3 bindings for libCombine
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: swig

%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains %{summary}.

This is the version for Python 3.
%endif

%prep
%autosetup -n libCombine-%{commit}

# Fix library destination
sed -e 's|CMAKE_INSTALL_LIBDIR lib|CMAKE_INSTALL_LIBDIR %{_lib}|g' -i CMakeLists.txt
sed -e 's|PACKAGE_CONFIG_DIR lib/cmake|PACKAGE_CONFIG_DIR %{_lib}/cmake|g' -i CMakeLists.txt

%build
mkdir -p build && cd build
export CXXFLAGS="%{optflags} -Wl,--as-needed"
%cmake -Wno-cpp -DCMAKE_BUILD_TYPE:STRING=Release \
 -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} -DLIBCOMBINE_SHARED_VERSION:BOOL=ON -DLIBCOMBINE_SKIP_SHARED_LIBRARY:BOOL=OFF \
 -DCMAKE_VERBOSE_MAKEFILE:BOOL=TRUE -DCMAKE_COLOR_MAKEFILE:BOOL=ON -DWITH_CHECK:BOOL=ON \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES -Dsbml-static_DIR:PATH=%{_libdir}/cmake \
 -DLIBSBML_LIBRARY:FILEPATH=%{_libdir}/libsbml.so -DLIBSBML_SHARED:BOOL=ON \
 -DZIPPER_LIBRARY:FILEPATH=%{_libdir}/libZipper.so \
 -DZIPPER_INCLUDE_DIR:PATH=%{_includedir}/zipper -DEXTRA_LIBS:STRING="numl;sbml;xml2;bz2;z;m;dl;expat" \
%if %{with python3}
 -DWITH_PYTHON:BOOL=ON \
 -DPYTHON_INCLUDE_DIR:PATH=%{_includedir}/python%{python3_version}m \
 -DPYTHON_LIBRARY:FILEPATH=%{_libdir}/libpython%{python3_version}m.so \
 -DPYTHON_EXECUTABLE:FILEPATH=%{__python3} \
%endif
..

%make_build

%install
%make_install -C build

%ldconfig_scriptlets

%if 0%{?with_check}
%check
pushd build
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
ctest --force-new-ctest-process -V
%endif

%files
%doc README.md VERSION.txt
%license LICENSE.md
%{_libdir}/libCombine.so.*

%files devel
%{_libdir}/libCombine.so
%{_libdir}/cmake/Combine-config-*.cmake
%{_libdir}/cmake/Combine-config.cmake
%{_includedir}/combine/
%{_includedir}/omex/

%files static
%{_libdir}/libCombine-static.a
%{_libdir}/cmake/Combine-static-*.cmake

%if %{with python3}
%files -n python3-%{name}
%{python3_sitearch}/libcombine.pth
%{python3_sitearch}/libcombine/
%endif

%changelog
* Mon Apr 30 2018 Antonio Trande <sagitter@fedoraproject.org> - 0.2.2-3.20180426git8902b68
- Specify source code's licenses

* Sun Apr 29 2018 Antonio Trande <sagitter@fedoraproject.org> - 0.2.2-2.20180426git8902b68
- Build Python3 binding

* Thu Apr 26 2018 Antonio Trande <sagitter@fedoraproject.org> - 0.2.2-1.20180426git8902b68
- First package
